lambdaisland.config.cli

Config provider for lambdaisland/cli

Goes well with specifying :key on command line flags. The cli dependency is BYO, you need to add it to your project dependencies explicitly. Use 0.19.78 or later for provenance tracking support.

Config provider for lambdaisland/cli

Goes well with specifying `:key` on command line flags. The cli dependency is
BYO, you need to add it to your project dependencies explicitly. Use 0.19.78
or later for provenance tracking support.
raw docstring

lambdaisland.config.munge

Logic for how to turn a config key and possibly an app prefix into various things we can look up.

Env vars:

  • uppercased
  • dashes and slashes become underscores
  • prefix is separated from key with __
  • special characters are munged see ([[clojure.core/munge]])
  • e.g. prefix: "my-app", key: :service/api-key -> MY_APP__SERVICE_API_KEY

File names:

  • slashes become dashes
  • prefix is separated from key with -
  • characters *?<>! are stripped
  • e.g. prefix: "my-app", key: :service/api-key! -> my-app-service-api-key
Logic for how to turn a config key and possibly an app prefix into various
things we can look up.

Env vars:
- uppercased
- dashes and slashes become underscores
- prefix is separated from key with `__`
- special characters are munged see ([[clojure.core/munge]])
- e.g. prefix: "my-app", key: `:service/api-key` -> MY_APP__SERVICE_API_KEY

File names:
- slashes become dashes
- prefix is separated from key with `-`
- characters `*?<>!` are stripped
- e.g. prefix: "my-app", key: `:service/api-key!` -> my-app-service-api-key
raw docstring

lambdaisland.config.systemd-creds

Provider for systemd-creds style credentials. These are configured in .service files with LoadCredential, LoadCredentialEncrypted, ImportCredential, ImportEncryptedCredential, see man 5 systemd.exec

Provider for systemd-creds style credentials. These are configured in .service
files with LoadCredential, LoadCredentialEncrypted, ImportCredential,
ImportEncryptedCredential, see `man 5 systemd.exec`
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries