(-reload this)(-source this k)(-value this k)(create {:keys [prefix env-vars java-system-props local-config xdg-config
prefix-env prefix-props]
:as opts
:or {env-vars true
java-system-props true
local-config true
xdg-config true
prefix-env true
prefix-props true}})(env-key {:keys [prefix env] :as opts})The current environment name, as a keyword, for instance :dev, :prod, or :test
Checked in order
:env explicitly passed inPREFIX__ENV env var, based on the configured :prefix, uppercasedprefix.env Java system property (use Java CLI flag -D, e.g. -Dprefix.env=prod)CI=true then :test (convention used by most CI providers):devThe current environment name, as a keyword, for instance `:dev`, `:prod`, or `:test` Checked in order - `:env` explicitly passed in - `PREFIX__ENV` env var, based on the configured `:prefix`, uppercased - `prefix.env` Java system property (use Java CLI flag `-D`, e.g. `-Dprefix.env=prod`) - if env var `CI=true` then `:test` (convention used by most CI providers) - otherwise: `:dev`
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |