Config provider for lambdaisland/cli
Goes well with specifying :key on command line flags. The cli dependency is
BYO, you need to add it to your project dependencies explicitly. Use 0.19.78
or later for provenance tracking support.
Config provider for lambdaisland/cli Goes well with specifying `:key` on command line flags. The cli dependency is BYO, you need to add it to your project dependencies explicitly. Use 0.19.78 or later for provenance tracking support.
(add-provider config)(add-provider config !opts)Handle lambdaisland/cli command line args for config.
Update a config to add a provider which looks up values in lambdaisland.cli/opts, or another var/atom of your choice containing the opts map coming from lambdaisland/cli. It will take precedence over other providers.
Handle lambdaisland/cli command line args for config. Update a config to add a provider which looks up values in lambdaisland.cli/*opts*, or another var/atom of your choice containing the opts map coming from lambdaisland/cli. It will take precedence over other providers.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |