lambdaisland.config


ConfigProvidercljprotocol

-reloadclj

(-reload this)

-sourceclj

(-source this k)

-valueclj

(-value this k)
source

createclj

(create {:keys [prefix env-vars java-system-props local-config xdg-config
                prefix-env prefix-props]
         :as opts
         :or {env-vars true
              java-system-props true
              local-config true
              xdg-config true
              prefix-env true
              prefix-props true}})
source

ensure-aeroclj

(ensure-aero path cache opts)
source

entriesclj

(entries config)
source

env-keyclj

(env-key {:keys [prefix env] :as opts})

The current environment name, as a keyword, for instance :dev, :prod, or :test

Checked in order

  • :env explicitly passed in
  • PREFIX__ENV env var, based on the configured :prefix, uppercased
  • prefix.env Java system property (use Java CLI flag -D, e.g. -Dprefix.env=prod)
  • if env var CI=true then :test (convention used by most CI providers)
  • otherwise: :dev
The current environment name, as a keyword, for instance `:dev`, `:prod`, or `:test`

Checked in order
- `:env` explicitly passed in
- `PREFIX__ENV` env var, based on the configured `:prefix`, uppercased
- `prefix.env` Java system property (use Java CLI flag `-D`, e.g. `-Dprefix.env=prod`)
- if env var `CI=true` then `:test` (convention used by most CI providers)
- otherwise: `:dev`
sourceraw docstring

getclj

(get config k)
source

get-entryclj

(get-entry {:keys [providers values] :as config} k)
source

new-configclj

(new-config env providers)
(new-config env providers prefix)
source

register-printclj

(register-print klz data-fn)
source

reload!clj

(reload! config)
source

sourceclj

(source config k)
source

sourcesclj

(sources config)
source

valuesclj

(values config)
source

cljdoc builds & hosts documentation for Clojure/Script libraries